@@ -14,30 +14,23 @@ var show_relation_lines = true;
 var always_show_text = false;
 
 AJAX.registerTeardown('pmd/move.js', function () {
-    if ($.FullScreen.supported) {
-        $(document).unbind($.FullScreen.prefix + 'fullscreenchange');
-    }
-
+    $(document).off('fullscreenchange');
     $('#selflink').show();
 });
 
 AJAX.registerOnload('pmd/move.js', function () {
     $('#page_content').css({'margin-left': '3px'});
-    if ($.FullScreen.supported) {
-        $(document).fullScreenChange(function () {
-            if (! $.FullScreen.isFullScreen()) {
-                $('#page_content').removeClass('content_fullscreen')
-                    .css({'width': 'auto', 'height': 'auto'});
-                var $img = $('#toggleFullscreen').find('img');
-                var $span = $img.siblings('span');
-                $span.text($span.data('enter'));
-                $img.attr('src', $img.data('enter'))
-                    .attr('title', $span.data('enter'));
-            }
-        });
-    } else {
-        $('#toggleFullscreen').hide();
-    }
+    $(document).on('fullscreenchange', function () {
+        if (! $.fn.fullScreen()) {
+            $('#page_content').removeClass('content_fullscreen')
+                .css({'width': 'auto', 'height': 'auto'});
+            var $img = $('#toggleFullscreen').find('img');
+            var $span = $img.siblings('span');
+            $span.text($span.data('enter'));
+            $img.attr('src', $img.data('enter'))
+                .attr('title', $span.data('enter'));
+        }
+    });
 
     $('#selflink').hide();
 });
@@ -582,18 +575,18 @@ function Toggle_fullscreen()
     var value_sent = '';
     var $img = $('#toggleFullscreen').find('img');
     var $span = $img.siblings('span');
-    if (! $.FullScreen.isFullScreen()) {
+    var $content = $('#page_content');
+    if (! $content.fullScreen()) {
         $img.attr('src', $img.data('exit'))
             .attr('title', $span.data('exit'));
         $span.text($span.data('exit'));
-        $('#page_content')
+        $content
             .addClass('content_fullscreen')
-            .css({'width': screen.width - 5, 'height': screen.height - 5})
-            .requestFullScreen();
+            .css({'width': screen.width - 5, 'height': screen.height - 5});
         value_sent = 'on';
-    }
-    if ($.FullScreen.isFullScreen()) {
-        $.FullScreen.cancelFullScreen();
+        $content.fullScreen(true);
+    } else {
+        $content.fullScreen(false);
         value_sent = 'off';
     }
     saveValueInConfig('full_screen', value_sent);
@@ -649,7 +642,7 @@ function Save2(callback)
 {
     if (pmd_tables_enabled) {
         var poststr = '&operation=savePage&save_page=same&ajax_request=true';
-        poststr += '&server=' + server + '&db=' + db + '&token=' + token + '&selected_page=' + selected_page;
+        poststr += '&server=' + server + '&db=' + db + '&token=' + PMA_commonParams.get('token') + '&selected_page=' + selected_page;
         poststr += Get_url_pos();
 
         var $msgbox = PMA_ajaxShowMessage(PMA_messages.strProcessingRequest);
@@ -736,7 +729,7 @@ function Save3(callback)
         var $form = $('<form action="db_designer.php" method="post" name="save_page" id="save_page" class="ajax"></form>')
             .append('<input type="hidden" name="server" value="' + server + '" />')
             .append('<input type="hidden" name="db" value="' + db + '" />')
-            .append('<input type="hidden" name="token" value="' + token + '" />')
+            .append('<input type="hidden" name="token" value="' + PMA_commonParams.get('token') + '" />')
             .append('<input type="hidden" name="operation" value="savePage" />')
             .append('<input type="hidden" name="save_page" value="new" />')
             .append('<label for="selected_value">' + PMA_messages.strPageName +
@@ -781,7 +774,7 @@ function Edit_pages()
         };
 
         var $msgbox = PMA_ajaxShowMessage();
-        var params = 'ajax_request=true&dialog=edit&server=' + server + '&token=' + token + '&db=' + db;
+        var params = 'ajax_request=true&dialog=edit&server=' + server + '&token=' + PMA_commonParams.get('token') + '&db=' + db;
         $.get("db_designer.php", params, function (data) {
             if (data.success === false) {
                 PMA_ajaxShowMessage(data.error, false);
@@ -861,7 +854,7 @@ function Delete_pages()
     };
 
     var $msgbox = PMA_ajaxShowMessage();
-    var params = 'ajax_request=true&dialog=delete&server=' + server + '&token=' + token + '&db=' + db;
+    var params = 'ajax_request=true&dialog=delete&server=' + server + '&token=' + PMA_commonParams.get('token') + '&db=' + db;
     $.get("db_designer.php", params, function (data) {
         if (data.success === false) {
             PMA_ajaxShowMessage(data.error, false);
@@ -960,7 +953,7 @@ function Save_as()
     };
 
     var $msgbox = PMA_ajaxShowMessage();
-    var params = 'ajax_request=true&dialog=save_as&server=' + server + '&token=' + token + '&db=' + db;
+    var params = 'ajax_request=true&dialog=save_as&server=' + server + '&token=' + PMA_commonParams.get('token') + '&db=' + db;
     $.get("db_designer.php", params, function (data) {
         if (data.success === false) {
             PMA_ajaxShowMessage(data.error, false);
@@ -1037,7 +1030,7 @@ function Export_pages()
         $(this).dialog('close');
     };
     var $msgbox = PMA_ajaxShowMessage();
-    var params = 'ajax_request=true&dialog=export&server=' + server + '&token=' + token + '&db=' + db + '&selected_page=' + selected_page;
+    var params = 'ajax_request=true&dialog=export&server=' + server + '&token=' + PMA_commonParams.get('token') + '&db=' + db + '&selected_page=' + selected_page;
     $.get("db_designer.php", params, function (data) {
         if (data.success === false) {
             PMA_ajaxShowMessage(data.error, false);
@@ -1084,7 +1077,7 @@ function Load_page(page) {
         if (page !== null) {
             param_page = '&page=' + page;
         }
-        $('<a href="db_designer.php?server=' + server + '&db=' + db + '&token=' + token + param_page + '"></a>')
+        $('<a href="db_designer.php?server=' + server + '&db=' + db + '&token=' + PMA_commonParams.get('token') + param_page + '"></a>')
             .appendTo($('#page_content'))
             .click();
     } else {
@@ -1132,7 +1125,7 @@ function Angular_direct()
 
 function saveValueInConfig(index_sent, value_sent) {
     $.post('db_designer.php',
-        {operation: 'save_setting_value', index: index_sent, ajax_request: true, server: server, token: token, value: value_sent},
+        {operation: 'save_setting_value', index: index_sent, ajax_request: true, server: server, token: PMA_commonParams.get('token'), value: value_sent},
         function (data) {
         if (data.success === false) {
             PMA_ajaxShowMessage(data.error, false);
@@ -1212,7 +1205,7 @@ function Click_field(T, f, PK) // table field
 
         var $msgbox = PMA_ajaxShowMessage(PMA_messages.strProcessingRequest);
         $.post('db_designer.php',
-            {operation: 'setDisplayField', ajax_request: true, server: server, token: token, db: db, table: T, field: f},
+            {operation: 'setDisplayField', ajax_request: true, server: server, token: PMA_commonParams.get('token'), db: db, table: T, field: f},
             function (data) {
             if (data.success === false) {
                 PMA_ajaxShowMessage(data.error, false);
@@ -1227,7 +1220,7 @@ function Click_field(T, f, PK) // table field
 function New_relation()
 {
     document.getElementById('layer_new_relation').style.display = 'none';
-    link_relation += '&server=' + server + '&db=' + db + '&token=' + token;
+    link_relation += '&server=' + server + '&db=' + db + '&token=' + PMA_commonParams.get('token');
     link_relation += '&on_delete=' + document.getElementById('on_delete').value + '&on_update=' + document.getElementById('on_update').value;
     link_relation += '&operation=addNewRelation&ajax_request=true';
 
@@ -1458,7 +1451,7 @@ function Canvas_click(id, event)
 function Upd_relation()
 {
     document.getElementById('layer_upd_relation').style.display = 'none';
-    link_relation += '&server=' + server + '&db=' + db + '&token=' + token;
+    link_relation += '&server=' + server + '&db=' + db + '&token=' + PMA_commonParams.get('token');
     link_relation += '&operation=removeRelation&ajax_request=true';
 
     var $msgbox = PMA_ajaxShowMessage(PMA_messages.strProcessingRequest);
