@@ -7,6 +7,9 @@
  */
 namespace PMA\libraries;
 
+use PMA\libraries\URL;
+use PMA\libraries\Sanitize;
+
 /**
  * Collects information about which JavaScript
  * files and objects are necessary to render
@@ -30,14 +33,6 @@ class Scripts
      * @var array of strings
      */
     private $_code;
-    /**
-     * An array of event names to bind and javascript code
-     * snippets to fire for the corresponding events
-     *
-     * @access private
-     * @var array
-     */
-    private $_events;
 
     /**
      * Returns HTML code to include javascript file.
@@ -51,11 +46,10 @@ class Scripts
         $first_dynamic_scripts = "";
         $dynamic_scripts = "";
         $scripts = array();
-        $separator = PMA_URL_getArgSeparator();
+        $separator = URL::getArgSeparator();
         foreach ($files as $value) {
-            if (mb_strpos($value['filename'], "?") !== false) {
-                $file_name = $value['filename'] . $separator
-                    . Header::getVersionParameter();
+            if (mb_strpos($value['filename'], ".php") !== false) {
+                $file_name = $value['filename'] . URL::getCommon($value['params'] + array('v' => PMA_VERSION));
                 if ($value['before_statics'] === true) {
                     $first_dynamic_scripts
                         .= "<script data-cfasync='false' type='text/javascript' "
@@ -68,22 +62,11 @@ class Scripts
                 continue;
             }
             $include = true;
-            if ($value['conditional_ie'] !== false
-                && PMA_USR_BROWSER_AGENT === 'IE'
-            ) {
-                if ($value['conditional_ie'] === true) {
-                    $include = true;
-                } else if ($value['conditional_ie'] == PMA_USR_BROWSER_VER) {
-                    $include = true;
-                } else {
-                    $include = false;
-                }
-            }
             if ($include) {
                 $scripts[] = "scripts%5B%5D=" . $value['filename'];
             }
         }
-        $separator = PMA_URL_getArgSeparator();
+        $separator = URL::getArgSeparator();
         $static_scripts = '';
         // Using chunks of 10 files to avoid too long URLs
         // as some servers are set to 512 bytes URL limit
@@ -110,7 +93,6 @@ class Scripts
     {
         $this->_files  = array();
         $this->_code   = '';
-        $this->_events = array();
 
     }
 
@@ -118,8 +100,6 @@ class Scripts
      * Adds a new file to the list of scripts
      *
      * @param string $filename       The name of the file to include
-     * @param bool   $conditional_ie Whether to wrap the script tag in
-     *                               conditional comments for IE
      * @param bool   $before_statics Whether this dynamic script should be
      *                               included before the static ones
      *
@@ -127,8 +107,8 @@ class Scripts
      */
     public function addFile(
         $filename,
-        $conditional_ie = false,
-        $before_statics = false
+        $before_statics = false,
+        $params = array()
     ) {
         $hash = md5($filename);
         if (!empty($this->_files[$hash])) {
@@ -139,7 +119,7 @@ class Scripts
         $this->_files[$hash] = array(
             'has_onload' => $has_onload,
             'filename' => $filename,
-            'conditional_ie' => $conditional_ie,
+            'params' => $params,
             'before_statics' => $before_statics
         );
     }
@@ -147,16 +127,14 @@ class Scripts
     /**
      * Add new files to the list of scripts
      *
-     * @param array $filelist       The array of file names
-     * @param bool  $conditional_ie Whether to wrap the script tag in
-     *                              conditional comments for IE
+     * @param array $filelist The array of file names
      *
      * @return void
      */
-    public function addFiles($filelist, $conditional_ie = false)
+    public function addFiles($filelist)
     {
         foreach ($filelist as $filename) {
-            $this->addFile($filename, $conditional_ie);
+            $this->addFile($filename);
         }
     }
 
@@ -195,24 +173,6 @@ class Scripts
         $this->_code .= "$code\n";
     }
 
-    /**
-     * Adds a new event to the list of events
-     *
-     * @param string $event    The name of the event to register
-     * @param string $function The code to execute when the event fires
-     *                         E.g: 'function () { doSomething(); }'
-     *                         or 'doSomething'
-     *
-     * @return void
-     */
-    public function addEvent($event, $function)
-    {
-        $this->_events[] = array(
-            'event' => $event,
-            'function' => $function
-        );
-    }
-
     /**
      * Returns a list with filenames and a flag to indicate
      * whether to register onload events for this file
@@ -227,13 +187,11 @@ class Scripts
             if (strpos($file['filename'], "?") !== false) {
                 continue;
             }
+            $retval[] = array(
+                'name' => $file['filename'],
+                'fire' => $file['has_onload']
+            );
 
-            if (! $file['conditional_ie'] || PMA_USR_BROWSER_AGENT == 'IE') {
-                $retval[] = array(
-                    'name' => $file['filename'],
-                    'fire' => $file['has_onload']
-                );
-            }
         }
         return $retval;
     }
@@ -257,7 +215,7 @@ class Scripts
         foreach ($this->_files as $file) {
             $code .= sprintf(
                 '.add("%s",%d)',
-                PMA_escapeJsString($file['filename']),
+                Sanitize::escapeJsString($file['filename']),
                 $file['has_onload'] ? 1 : 0
             );
         }
@@ -268,7 +226,7 @@ class Scripts
         foreach ($this->_files as $file) {
             if ($file['has_onload']) {
                 $code .= 'AJAX.fireOnload("';
-                $code .= PMA_escapeJsString($file['filename']);
+                $code .= Sanitize::escapeJsString($file['filename']);
                 $code .= '");';
             }
         }
@@ -278,13 +236,6 @@ class Scripts
         $retval .= '<script data-cfasync="false" type="text/javascript">';
         $retval .= "// <![CDATA[\n";
         $retval .= $this->_code;
-        foreach ($this->_events as $js_event) {
-            $retval .= sprintf(
-                "$(window).bind('%s', %s);\n",
-                $js_event['event'],
-                $js_event['function']
-            );
-        }
         $retval .= '// ]]>';
         $retval .= '</script>';
 
