@@ -7,6 +7,8 @@
  */
 namespace PMA\libraries\config;
 
+use PMA\libraries\URL;
+
 /**
  * Performs various compatibility, security and consistency checks on current config
  *
@@ -388,13 +390,13 @@ class ServerConfigChecks
         );
         $sAllowArbitraryServerWarn = sprintf(
             $sAllowArbitraryServerWarn,
-            '[a@?page=form' . PMA_URL_getCommon(array(), 'html', '&')
+            '[a@?page=form' . URL::getCommon(array(), '&')
             . '&amp;formset=Features#tab_Security]',
             '[/a]',
-            '[a@?page=form' . PMA_URL_getCommon(array(), 'html', '&')
+            '[a@?page=form' . URL::getCommon(array(), '&')
             . '&amp;formset=Features#tab_Security]',
             '[/a]',
-            '[a@?page=form' . PMA_URL_getCommon(array(), 'html', '&')
+            '[a@?page=form' . URL::getCommon(array(), '&')
             . '&amp;formset=Features#tab_Security]',
             '[/a]'
         );
@@ -410,7 +412,7 @@ class ServerConfigChecks
         );
         $sBZipDumpWarning = sprintf(
             $sBZipDumpWarning,
-            '[a@?page=form' . PMA_URL_getCommon(array(), 'html', '&')
+            '[a@?page=form' . URL::getCommon(array(), '&')
             . '&amp;formset=Features#tab_Import_export]',
             '[/a]', '%s'
         );
@@ -425,7 +427,7 @@ class ServerConfigChecks
         );
         $sGZipDumpWarning = sprintf(
             $sGZipDumpWarning,
-            '[a@?page=form' . PMA_URL_getCommon(array(), 'html', '&')
+            '[a@?page=form' . URL::getCommon(array(), '&')
             . '&amp;formset=Features#tab_Import_export]',
             '[/a]',
             '%s'
@@ -437,7 +439,7 @@ class ServerConfigChecks
         );
         $sLoginCookieValidityWarn = sprintf(
             $sLoginCookieValidityWarn,
-            '[a@?page=form' . PMA_URL_getCommon(array(), 'html', '&')
+            '[a@?page=form' . URL::getCommon(array(), '&')
             . '&amp;formset=Features#tab_Security]',
             '[/a]',
             '[a@' . PMA_getPHPDocLink(
@@ -453,7 +455,7 @@ class ServerConfigChecks
         );
         $sLoginCookieValidityWarn2 = sprintf(
             $sLoginCookieValidityWarn2,
-            '[a@?page=form' . PMA_URL_getCommon(array(), 'html', '&')
+            '[a@?page=form' . URL::getCommon(array(), '&')
             . '&amp;formset=Features#tab_Security]',
             '[/a]'
         );
@@ -464,10 +466,10 @@ class ServerConfigChecks
         );
         $sLoginCookieValidityWarn3 = sprintf(
             $sLoginCookieValidityWarn3,
-            '[a@?page=form' . PMA_URL_getCommon(array(), 'html', '&')
+            '[a@?page=form' . URL::getCommon(array(), '&')
             . '&amp;formset=Features#tab_Security]',
             '[/a]',
-            '[a@?page=form' . PMA_URL_getCommon(array(), 'html', '&')
+            '[a@?page=form' . URL::getCommon(array(), '&')
             . '&amp;formset=Features#tab_Security]',
             '[/a]'
         );
@@ -479,10 +481,10 @@ class ServerConfigChecks
         );
         $sSecurityInfoMsg = sprintf(
             $sSecurityInfoMsg,
-            '[a@?page=servers' . PMA_URL_getCommon(array(), 'html', '&')
+            '[a@?page=servers' . URL::getCommon(array(), '&')
             . '&amp;mode=edit&amp;id=%1$d#tab_Server_config]',
             '[/a]',
-            '[a@?page=form' . PMA_URL_getCommon(array(), 'html', '&')
+            '[a@?page=form' . URL::getCommon(array(), '&')
             . '&amp;formset=Features#tab_Security]',
             '[/a]'
         );
@@ -495,7 +497,7 @@ class ServerConfigChecks
         );
         $sServerAuthConfigMsg = sprintf(
             $sServerAuthConfigMsg,
-            '[a@?page=servers' . PMA_URL_getCommon(array(), 'html', '&')
+            '[a@?page=servers' . URL::getCommon(array(), '&')
             . '&amp;mode=edit&amp;id=%1$d#tab_Server]',
             '[/a]'
         );
@@ -505,7 +507,7 @@ class ServerConfigChecks
         );
         $sZipDumpExportWarn = sprintf(
             $sZipDumpExportWarn,
-            '[a@?page=form' . PMA_URL_getCommon(array(), 'html', '&')
+            '[a@?page=form' . URL::getCommon(array(), '&')
             . '&amp;formset=Features#tab_Import_export]',
             '[/a]',
             '%s'
@@ -516,7 +518,7 @@ class ServerConfigChecks
         );
         $sZipDumpImportWarn = sprintf(
             $sZipDumpImportWarn,
-            '[a@?page=form' . PMA_URL_getCommon(array(), 'html', '&')
+            '[a@?page=form' . URL::getCommon(array(), '&')
             . '&amp;formset=Features#tab_Import_export]',
             '[/a]',
             '%s'
